Subject: [PATCH 03/10] system: Use /run/privileged/bin in search paths.

From: Tobias Geerinckx-Rice <[email-masked]>
Date: Sun, 5 Feb 2023 01:00:12 +0100

* gnu/system.scm (operating-system-etc-service):
Substitute /run/privileged/bin for deprecated /run/setuid-programs.
---
 gnu/system.scm | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/gnu/system.scm b/gnu/system.scm
index 85380136e2..446439bcac 100644
--- a/gnu/system.scm
+++ b/gnu/system.scm
@@ -987,10 +987,10 @@ (define* (operating-system-etc-service os)
           (plain-file "login.defs"
                       (string-append
                         "# Default paths for non-login shells started by su(1).\n"
-                        "ENV_PATH    /run/setuid-programs:"
+                        "ENV_PATH    /run/privileged/bin:"
                         "/run/current-system/profile/bin:"
                         "/run/current-system/profile/sbin\n"
-                        "ENV_SUPATH  /run/setuid-programs:"
+                        "ENV_SUPATH  /run/privileged/bin:"
                         "/run/current-system/profile/bin:"
                         "/run/current-system/profile/sbin\n"
 
@@ -1054,8 +1054,8 @@ (define* (operating-system-etc-service os)
   fi
 done
 
-# Prepend setuid programs.
-export PATH=/run/setuid-programs:$PATH
+# Prepend privileged programs.
+export PATH=/run/privileged/bin:$PATH
 
 # Arrange so that ~/.config/guix/current/share/info comes first.
 export INFOPATH=\"$HOME/.config/guix/current/share/info:$INFOPATH\"
-- 
2.39.1